"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.promptForCreateApp = exports.promptForInit = exports.promptForCreateOrganization = exports.promptForUploadFile = exports.promptForLogin = void 0;
const create_app_1 = require("../commands/create-app");
const inquirer = require("inquirer");
function promptForLogin() {
    return __awaiter(this, void 0, void 0, function* () {
        const result = yield inquirer.prompt([
            {
                type: "list",
                name: "provider",
                message: "Select your provider",
                choices: ["github", "gitlab", "bitbucket"],
            },
        ]);
        return result;
    });
}
exports.promptForLogin = promptForLogin;
function promptForUploadFile() {
    return __awaiter(this, void 0, void 0, function* () {
        const questions = [
            {
                type: "input",
                name: "path",
                message: "Path to file (default -> ./):",
            },
            {
                type: "list",
                name: "protocol",
                message: "Upload protocol:",
                choices: ["arweave", "ipfs-filecoin", "ipfs"],
            },
            {
                type: "input",
                name: "projectName",
                message: "Project name (default -> auto generated):",
            },
            {
                type: "input",
                name: "organizationId",
                message: "Organization where project will be created (default - from settings):",
            },
        ];
        return inquirer.prompt(questions);
    });
}
exports.promptForUploadFile = promptForUploadFile;
function promptForCreateOrganization() {
    return __awaiter(this, void 0, void 0, function* () {
        const questions = [
            {
                type: "input",
                name: "name",
                message: "Name of the organization (default -> auto generated):",
            },
            {
                type: "input",
                name: "username",
                message: "Username of the organization (default -> auto generated):",
            },
        ];
        return inquirer.prompt(questions);
    });
}
exports.promptForCreateOrganization = promptForCreateOrganization;
function promptForInit() {
    return __awaiter(this, void 0, void 0, function* () {
        const questions = [
            {
                type: "input",
                name: "project",
                message: "Project name:",
            },
            {
                type: "input",
                name: "protocol",
                message: "Upload protocol:",
            },
            {
                type: "input",
                name: "path",
                message: "Path to directory (default -> ./):",
            },
        ];
        return inquirer.prompt(questions);
    });
}
exports.promptForInit = promptForInit;
function promptForCreateApp() {
    return __awaiter(this, void 0, void 0, function* () {
        inquirer
            .prompt([
            {
                type: "list",
                name: "projectType",
                message: "What type of project do you want to create?",
                choices: ["Default app", "Start from a template"],
            },
        ])
            .then((answers) => {
            if (answers.projectType === "Default app") {
                inquirer
                    .prompt([
                    {
                        type: "list",
                        name: "templateType",
                        message: "Choose a default app type:",
                        choices: ["React", "Next.js"],
                    },
                    {
                        type: "input",
                        name: "projectName",
                        message: "Enter project name:",
                    },
                ])
                    .then((answers) => __awaiter(this, void 0, void 0, function* () {
                    console.log(`Creating a new default ${answers.templateType} project named ${answers.projectName}. Time to become a wizard 🔮`);
                    const url = (0, create_app_1.getTemplateUrlMapping)(answers.templateType);
                    yield (0, create_app_1.createApp)(url, answers.projectName);
                }));
            }
            else if (answers.projectType === "Start from a template") {
                inquirer
                    .prompt([
                    {
                        type: "list",
                        name: "templateType",
                        message: "Choose a template:",
                        choices: ["Portfolio", "NFT Drop"],
                    },
                    {
                        type: "input",
                        name: "projectName",
                        message: "Enter project name:",
                    },
                ])
                    .then((answers) => __awaiter(this, void 0, void 0, function* () {
                    if (!answers.projectName) {
                        throw new Error("Project name was not provided");
                    }
                    console.log(`Creating a new spheron project from template ${answers.templateType} with project name ${answers.projectName}. Time to become a wizard 🔮`);
                    const url = (0, create_app_1.getTemplateUrlMapping)(answers.templateType);
                    yield (0, create_app_1.createApp)(url, answers.projectName);
                }));
            }
        });
    });
}
exports.promptForCreateApp = promptForCreateApp;
